# from auth.models import User
# from contrib.admin.options import CollectionAdmin
# from django.contrib import admin

# class UserAdmin(CollectionAdmin):
#
#     list_display = ( 'username', )
#
# admin.site.register(User, UserAdmin)

# class ExtendedSliderAdmin(admin.ModelAdmin):
#     """
#     Extendend slider admin
#     """
#     list_display = ('name', )
#     list_filter = ('created', )
#
# admin.site.register(ExtendedSlider, ExtendedSliderAdmin)